[![Documentation Status](https://readthedocs.org/projects/python-script-manager/badge/?version=latest)](https://python-script-manager.readthedocs.io/en/latest/?badge=latest)

# <img src="https://raw.githubusercontent.com/YunisDEV/myp/master/assets/myp.svg"/> Welcome to PSM

## What is PSM?
**PSM** is a tool that helps you to manage and develop your Python apps easily.

## Learn more about PSM

Full documentation is available at [ReadTheDocs](https://python-script-manager.readthedocs.io).